@@ -1,19 +1,20 @@
-from __future__ import print_function
 import logging
+import os
 
-from keystoneclient.auth.identity import generic
-from keystoneclient import session as keystone_session
+from keystoneauth1.identity import generic
+from keystoneauth1 import session as keystone_session
 
-from designateclient import shell
 from designateclient.v2 import client
 
 logging.basicConfig(level='DEBUG')
 
 auth = generic.Password(
-    auth_url=shell.env('OS_AUTH_URL'),
-    username=shell.env('OS_USERNAME'),
-    password=shell.env('OS_PASSWORD'),
-    tenant_name=shell.env('OS_TENANT_NAME'))
+    auth_url=os.environ.get('OS_AUTH_URL'),
+    username=os.environ.get('OS_USERNAME'),
+    password=os.environ.get('OS_PASSWORD'),
+    project_name=os.environ.get('OS_PROJECT_NAME'),
+    project_domain_id='default',
+    user_domain_id='default')
 
 session = keystone_session.Session(auth=auth, timeout=10)
 
